function [h,t,t0,np] = sv_model_ct_TG3c(n, PLo, LowSigma_s, CapLambda, ... 
  LowLambda, CapGamma, LowGamma, LowSigma_c, LowSigma_r, LowSigma_phi, ... 
  L_mean, Delta_CapK, Delta_LowK, CapOmega, h1, h2, G_T, G_R, fs, ... 
  CapK_los,num_channels,ts,cm_num)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Written by Sun Xu, Kim Chee Wee, B. Kannan & Francois Chin on 14/09/2004  
%   IEEE 802.15.4a UWB channel model for PHY proposal evaluation
%      continuous-time realization of modified S-V channel model
%
% Modified for use by 802.15.3c by Rick Roberts, 1 August 2006
%
% Input parameters:
%   detailed introduction of input parameters is at uwb_sv_params.m
%   num_channels  number of random realizations to generate
%
% Outputs
%   h is returned as a matrix with num_channels columns, each column 
%     holding a random realization of the channel model (an impulse response)
%   t is organized as h, but holds the time instances (in nsec) of the paths whose
%     signed amplitudes are stored in h
%   t0 is the arrival time of the first cluster for each realization
%   np is the number of paths for each realization.
%
% Thus, the k'th realization of the channel impulse response is the sequence 
%   of (time,value) pairs given by (t(1:np(k),k), h(1:np(k),k))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nlos=0;
std_shdw = 3;

switch cm_num
    
  case 1.1
    disp('  --> running SV model code for CM1.1')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end

  case 1.2
    disp('  --> running SV model code for CM1.2')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end

  case 1.3
    disp('  --> running SV model code for CM1.3')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end

  case 1.4
    disp('  --> running SV model code for CM1.4')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end

  case 1.5
    disp('  --> running SV model code for CM1.5')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end

  case 2
    disp('  --> running SV model code for CM2')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end

  case 3.1
    disp('  --> running SV model code for CM3.1')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end

  case 3.2
    disp('  --> running SV model code for CM3.2')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end
    
  case 4
    disp('  --> running SV model code for CM4')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end
    
  case 5
    disp('  --> running SV model code for CM5')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end
    
  case 6
    disp('  --> running SV model code for CM6')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end
    
  case 7
    disp('  --> running SV model code for CM7')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end
    
  case 8
    disp('  --> running SV model code for CM8')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end
    
  case 9.1
    disp('  --> running SV model code for CM9.1')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end
    
  case 9.2
    disp('  --> running SV model code for CM9.2')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end

  case 9.3
    disp('  --> running SV model code for CM9.3')
    % initialize and precompute some things
    std_L = 1/sqrt(2*CapLambda);      % std dev (nsec) of cluster arrival spacing
    std_lam = 1/sqrt(2*LowLambda); % std dev (nsec) of ray arrival spacing
    h_len = 1000;  % there must be a better estimate of # of paths than this
    ngrow = 1000; % amount to grow data structure if more paths are needed
    h = zeros(h_len,num_channels);
    t = zeros(h_len,num_channels);
    t0 = zeros(1,num_channels);
    np = zeros(1,num_channels);

    for k = 1:num_channels       % loop over number of channels
      tmp_h = zeros(size(h,1),1);
      tmp_t = zeros(size(h,1),1);
      if nlos == 1,
        Tc = (std_L*randn)^2 + (std_L*randn)^2;  % First cluster random arrival
      else
        Tc = 0;                   % First cluster arrival occurs at time 0
      end
      t0(k) = Tc;
      L = max(1, poissrnd(L_mean)); % number of clusters (at least 1 cluster)
      cluster_index = zeros(1,L);
      path_ix = 0;
      nak_m = [];
      for ncluster = 1:L
        % Determine Ray arrivals for each cluster
        Tr = 0;  % first ray arrival defined to be time 0 relative to cluster
        cluster_index(ncluster) = path_ix+1;  % remember the cluster location
        Mcluster = LowSigma_c*randn;
        Pcluster = 10*log10(exp(-1*Tc/CapGamma))+Mcluster; % total cluster power
        Pcluster = 10^(Pcluster*0.1);
        while (Tr < 10*LowGamma),
          t_val = (Tc+Tr);  % time of arrival of this ray
          h_val = (Pcluster/LowGamma)*exp(-Tr/LowGamma);
          path_ix = path_ix + 1;  % row index of this ray
          if path_ix > h_len,
            % grow the output structures to handle more paths as needed
            tmp_h = [tmp_h; zeros(ngrow,1)];
            tmp_t = [tmp_t; zeros(ngrow,1)];
            h = [h; zeros(ngrow,num_channels)];
            t = [t; zeros(ngrow,num_channels)];
            h_len = h_len + ngrow;
          end
          tmp_h(path_ix) = h_val;
          tmp_t(path_ix) = t_val;
          Tr = Tr + (std_lam*randn)^2 + (std_lam*randn)^2;
        end
        Tc = Tc + (std_L*randn)^2 + (std_L*randn)^2;
      end
      np(k) = path_ix;  % number of rays (or paths) for this realization
      [sort_tmp_t,sort_ix] = sort(tmp_t(1:np(k)));    % sort in ascending time order
      t(1:np(k),k) = sort_tmp_t;
      h(1:np(k),k) = tmp_h(sort_ix(1:np(k)));
    % now impose a log-normal shadowing on this realization
      fac = 10^(std_shdw*randn/20) / sqrt( h(1:np(k),k)' * h(1:np(k),k) );
      h(1:np(k),k) = h(1:np(k),k) * fac;
    end

  otherwise
    disp('  --> ERROR! unsupported channel number')

end; return;